# shazbot
> Sound Hierarchy Attribute Zeitgeist Before Oligarchy Take


Work in progress. Do not try this.

## Install

```
pip install git+https://github.com/drscotthawley/shazbot.git
```
(`pip install shazbot` won't work yet)

## How to use

Do Not attempt to use.
